=======
History
=======

2.0.0 (2024-04-01)
==================

- Updated some dependencies, notably hspatial 2, which entails
  htimeseries 6.

1.0.1 (2021-09-01)
==================

- Updated some dependencies, notably htimeseries 3. Python 3.7, 3.8 and
  3.9 are now supported.

1.0.0 (2020-01-05)
==================

- Now uses version 5 of hts file (i.e. different time step notation).

0.1.2 (2019-10-24)
==================

- Fixed a bug where hts files were opened in the wrong mode, with
  inconsistent results.

0.1.1 (2019-07-18)
==================

- Fixed a spurious RuntimeWarning.
- Improved error message if the altitude or location is missing in an
  input file.

0.1.0 (2019-06-21)
==================

- Initial release
